@@ -5,13 +5,13 @@ from matplotlib import pyplot as plt
 
 
 def benchmark(method_labels: list[str], func_input_generator: Callable,
-              matrix_sizes: list[int], sparsity_block_sizes: list[int], triton_block_sizes: list[int],
+              matrix_sizes: list[int], sparsity_block_sizes: list[int],
               *funcs_test_subject: Callable, y_lim_top: int = None):
     quantiles = [0.5, 0.2, 0.8]
     results = {}
 
-    for matrix_size, sparsity_block_size, triton_block_size in zip(matrix_sizes, sparsity_block_sizes, triton_block_sizes):
-        arguments = func_input_generator(matrix_size, sparsity_block_size, triton_block_size)
+    for matrix_size, sparsity_block_size in zip(matrix_sizes, sparsity_block_sizes):
+        arguments = func_input_generator(matrix_size, sparsity_block_size)
 
         for i, func_test_subject in enumerate(funcs_test_subject):
             func_ms_avg, func_ms_min, func_ms_max = triton.testing.do_bench(
